import UploadImage from '@/components/UploadImage';
import UploadVideo from '@/components/UploadVideo';
import { addBanner, getBannerdById, updataBanner } from '@/services/api/rotationChart';
import {
  PageContainer,
  ProForm,
  ProFormDigit,
  ProFormRadio,
  ProFormSelect,
  ProFormTextArea,
} from '@ant-design/pro-components';
import { history, useSearchParams } from '@umijs/max';
import { Card, Col, message, Row, Space } from 'antd';
import { useEffect, useRef, useState } from 'react';

export default (props) => {
  const [searchParams, setSearchParams] = useSearchParams();
  const id = searchParams.get('id');
  const [data, setData] = useState({});
  const formRef = useRef();
  useEffect(() => {
    if (id) {
      getBannerdById(id).then((res) => {
        console.log(res, '====---');
        setData(res);

        formRef.current.setFieldsValue(res);
      });
    }
  }, [id]);

  const onFinish = async (values) => {
    if (id) {
      // 修改
      updataBanner(id, { ...values }).then((res) => {
        message.success('修改成功');
        history.back();
      });
    } else {
      // 新增
      addBanner({ ...values }).then((res) => {
        message.success('添加成功');
        history.back();
      });
    }

    return false;
  };

  return (
    <PageContainer>
      <Card>
        <ProForm
          formRef={formRef}
          layout={'horizontal'}
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 16 }}
          onFinish={onFinish}
          initialValues={{ type: '1', state: '1' }}
          submitter={{
            searchConfig: {
              resetText: '返回',
            },
            onReset: () => history.back(),
            render: (props, doms) => {
              return (
                <Row>
                  <Col span={8} offset={8}>
                    <Space>{doms}</Space>
                  </Col>
                </Row>
              );
            },
          }}
        >
          <ProFormSelect
            name="type"
            width="md"
            label="轮播图类型"
            valueEnum={{
              1: '图片',
              2: '视频',
            }}
            placeholder="轮播图类型"
            rules={[{ required: true, message: 'Please select your country!' }]}
          />
          <ProForm.Item
            width="md"
            name="image"
            label="图片"
            // extra="longgggggggggggggggggggggggggggggggggg"
            // rules={[{ required: true, message: '请上传图片' }]}
          >
            <UploadImage />
          </ProForm.Item>
          <ProForm.Item noStyle shouldUpdate>
            {(form) => {
              console.log(form, '==');

              return form.getFieldValue('type') == '1' ? null : (
                <ProForm.Item
                  width="md"
                  name="video"
                  label="视频"
                  // extra="longgggggggggggggggggggggggggggggggggg"
                  // rules={[{ required: true, message: '请上传图片' }]}
                >
                  <UploadVideo />
                </ProForm.Item>
              );
            }}
          </ProForm.Item>
          <ProFormRadio.Group
            name="state"
            label="状态"
            radioType="button"
            options={[
              {
                label: '上架',
                value: '1',
              },
              {
                label: '下架',
                value: '2',
              },
            ]}
          />
          <ProFormDigit name="qz" label="权重" width="md" />
          <ProFormTextArea width="md" name="desc" label="描述" placeholder="请输入描述" />
        </ProForm>
      </Card>
    </PageContainer>
    // <ModalForm
    //   title={`${butttomTitle}`}
    //   trigger={
    //     <Button type="primary" {...butttomProps}>
    //       {butttomTitle}
    //     </Button>
    //   }
    //   autoFocusFirstInput
    //   initialValues={{ type: '1', ...data }}
    //   modalProps={{
    //     onCancel: () => console.log('run'),
    //   }}
    //   submitTimeout={2000}
    //   onFinish={onFinish}
    // >

    //   <ProFormText width="md" name="platform" label="平台名称" placeholder="请输入平台名称" />
    //   <ProFormText width="md" name="ipAddr" label="IP地址" placeholder="请输入IP地址" />
    //   {/* <ProFormText
    //     width="md"
    //     name="name"
    //     label="推送频率"
    //     tooltip="最长为 24 位"
    //     placeholder="请输入名称"
    //   /> */}
    //   <ProFormTimePicker width="md" name="pushTime" label="推送时间" />
    // </ModalForm>
  );
};
